@@ -5,7 +5,7 @@ import os
 from html2image import Html2Image
 import jinja2
 
-from tasks import Task
+from asup.tasks import Task
 
 
 def print_task(task: Task):
